# anya-dash

anya-dash is a Dash component library.

Get started with:

1. Install Dash and its dependencies: https://dash.plotly.com/installation
2. Install anya-dash `pip install anya_dash`
3. Run examples under the test folder `python {file_name}.py`
4. Visit http://localhost:8050 in your web browser
